<TS language="de_DE" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>&lt;br&gt;</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Eine neue Adresse erstellen</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Aktive Adresse in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Ausgewählte Adresse aus der Liste löschen</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Daten des aktiven Fensters exportieren</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportieren</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Wähle die Empfängeradresse</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Wähle die Empfangsadresse</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Dies sind Ihre Litecoin-Adressen für den Empfang von Zahlungen. Es wird empfohlen, für jede Transaktion eine neue Empfangsadresse zu verwenden.</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Export Adressliste</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komma getrenntes Dokument (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Export fehlgeschlagen</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(kein Etikett)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Passwort Dialog</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Neues Passwort</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Passwort anzeigen</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Geben Sie das neue Passwort Ihrer digitalen Geldbörse ein.&lt;br/&gt;Verwenden Sie bitte ein Passwort bestehend aus &lt;b&gt;zehn oder mehr zufälligen Zeichen&lt;/b&gt;, oder aus &lt;b&gt;acht oder mehr Wörtern&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Diese Aktion benötigt ihr Passwort zum entsperren der Wallet.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Brieftasche entschlüsseln</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Diese Operation benötigt Ihr Wallet-Passwort zum entschlüsseln der Wallet.</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Passwort ändern</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Geben Sie das alte und neue Passwort Ihrer Wallet ein.</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Brieftasche verschlüsselt</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>WICHTIG: Alle früheren Sicherungen, die Sie von Ihrer Wallet-Datei gemacht haben, sollten durch die neu erzeugte, verschlüsselte Wallet-Datei ersetzt werden. Sobald Sie die neue, verschlüsselte Wallet verwenden, werden frühere Sicherungen der unverschlüsselten Wallet-Datei aus Sicherheitsgründen nutzlos.</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Die Wallet-Verschlüsselung ist aufgrund eines internen Fehlers fehlgeschlagen. Ihre Wallet wurde nicht verschlüsselt.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Die eingegebenen Passwörter stimmen nicht überein.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Brieftasche entschlüsseln fehlgeschlagen</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Brieftaschen Passwort erfolgreich geändert</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netzmaske</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Übersicht</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Generelle Übersicht der Brieftasche </translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaktionen</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Programm beenden</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Informationen über Qt anzeigen</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Einstellungen...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Ändern Sie die Konfigurationsoptionen für %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Brieftasche verschlüsseln...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Sicherungskopie der Brieftasche...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Öffne &amp;URI...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Klicken Sie, um die Netzwerkaktivität zu deaktivieren.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Netzwerkaktivität wurde deaktiviert.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Synchronisiere Header (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindexiere Blöcke auf dem Datenträger...</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Wallet an einen anderen Ort sichern</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ändern Sie das Passwort, das für die Wallet-Verschlüsselung verwendet wird</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Debug Fenster</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Die Debugging- und Diagnosekonsole öffnen</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Nachricht &amp;bestätigen</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Empfangen</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;anzeigen / verstecken</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Das Hauptfenster ein- oder ausblenden</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Verschlüssele die Private Keys, die zu deiner Brieftasche gehören</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Nachrichten mit Ihrer Litecoin-Adresse signieren, um zu beweisen, dass sie Ihnen gehören</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Überprüfen Sie Nachrichten, um sicherzustellen, dass sie mit den angegebenen Litecoin-Adressen signiert wurden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Registerkarten-Symbolleiste</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Zeige Liste der benutzten Empfangsadressen und -etiketten</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indexiere Blöcke auf dem Datenträger...</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transaktionen danach sind noch nicht sichtbar.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Achtung</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Auf dem neuesten Stand</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Aufholen...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Menge: %1</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Überweisung gesendet</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Überweisung empfangen</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Ein schwerwiegender Fehler ist aufgetreten. Litecoin kann nicht mehr sicher fortfahren und beendet sich.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Anzahl:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nach Gebühr:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Betrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bestätigungen</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Etikett kopieren</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Transaktions ID kopieren</translation>
    </message>
    <message>
        <source>no</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(kein Etikett)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Adresse bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etikett</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresse</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Neue Sendeadresse</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Empfangsadresse bearbeiten</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Sendeadresse bearbeiten</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>Name</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>Version</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Willkommen</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Betrag</translation>
    </message>
    <message>
        <source>Enter a Litecoin address (e.g. %1)</source>
        <translation>Litecoin Adresse eingeben (z.B. %1)</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy label</source>
        <translation>Etikett kopieren</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Betrag kopieren</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Betrag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Brieftasche</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Anzahl:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gebühr:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nach Gebühr:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Menge kopieren</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(kein Etikett)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Betrag</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(kein Etikett)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>Adresse kopieren</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Etikett kopieren</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Betrag kopieren</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Transaktions ID kopieren</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bestätigt</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Export fehlgeschlagen</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Backup Failed</source>
        <translation>Sicherung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Sicherung erfolgreich</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Starting network threads...</source>
        <translation>Starte Netzwerk-Threads...</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Das ist die Gebühr für die Überweisung</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation>Überweisung muss mindestens einen Empfänger haben </translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Ungenügendes Guthaben</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Block Verzeichnis laden...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Brieftasche laden...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Neuscannen...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Laden abgeschlossen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
</TS>